# Taktile Profiling

[![pypi status](https://img.shields.io/pypi/v/taktile-cli.svg)](https://pypi.python.org/pypi/taktile-cli)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

This package is part of the Taktile ecosystem.

Taktile enables data science teams to industrialize, scale, and maintain machine learning models. Our ML development platform makes it easy to create your own end-to-end ML applications:

- Turn models into auto-scaling APIs in a few lines of code
- Easily add model tests
- Create and share model explanations through the Taktile UI

Find more information in our [docs](https://docs.taktile.com).
